@@ -193,7 +193,7 @@ class Hist(object):
         self.xedges.append(self.x[n - 1] + self.xerr[1][n - 1])
         self.width = [self.xedges[i + 1] - self.xedges[i] for i in range(n)]
         self.underflow, self.overflow = 0, 0
-        self.binlabels = []
+        self.binlabels = None
         self.entries = n
     def __getitem__(self, index):
         """Return contents of indexth bin: x.__getitem__(y) <==> x[y]"""
@@ -315,7 +315,7 @@ class Hist(object):
         """
         kwargs.pop('fmt', None)
         if xerr: kwargs['xerr'] = self.xerr
-        if yerr: kwargs['yerr'] = self.yerr
+        if yerr: kwargs['yerr'] = self._av_yerr()
         _load_pyplot()
         bar = plt.bar(self.xedges[0:-1], self.y, self.width, label=self.label,
                       **kwargs)
@@ -329,12 +329,12 @@ class Hist(object):
         All additional keyword arguments will be passed to pyplot.barh.
         """
         kwargs.pop('fmt', None)
-        if xerr: kwargs['xerr'] = self.yerr
+        if xerr: kwargs['xerr'] = self._av_yerr()
         if yerr: kwargs['yerr'] = self.xerr
         _load_pyplot()
         xcontent = [self.xedges[i] + self.width[i] * yoffset
                     for i in range(len(self.xedges) - 1)]
-        width = self.width * width
+        width = [x * width for x in self.width]
         barh = plt.barh(xcontent, self.y, width, label=self.label,
                        **kwargs)
         self._prepare_yaxis(label_rotation, label_alignment)
@@ -687,12 +687,17 @@ def _process_bin_labels(binlabels):
 def wilson_interval(numerator_array, denominator_array):
     eff, upper_err, lower_err = [], [], []
     for n, d in zip(numerator_array, denominator_array):
-        p = float(n) / d
-        s = math.sqrt(p * (1 - p) / d + 1 / (4 * d * d))
-        t = p + 1 / (2 * d)
-        eff.append(p)
-        upper_err.append(-p + 1/(1 + 1/d) * (t + s))
-        lower_err.append(+p - 1/(1 + 1/d) * (t - s))
+        try:
+            p = float(n) / d
+            s = math.sqrt(p * (1 - p) / d + 1 / (4 * d * d))
+            t = p + 1 / (2 * d)
+            eff.append(p)
+            upper_err.append(-p + 1/(1 + 1/d) * (t + s))
+            lower_err.append(+p - 1/(1 + 1/d) * (t - s))
+        except ZeroDivisionError:
+            eff.append(0)
+            upper_err.append(0)
+            lower_err.append(0)
     return eff, upper_err, lower_err
 
 if __name__ == "__main__":
