@@ -156,6 +156,10 @@ mc_color = (50, 150, 150) # Used if only files are present and value is not None
 data_fmt = 'o'            # Marker style for matplotlib
 data_marker = 4           # Marker style for ROOT
 
+#### Styles for --ratio
+ratio_max = None
+ratio_min = None
+
 #### Titles produced by --area-normalize and --normalize
 area_normalized_title = 'Fraction of Events in Bin'
 file_normalized_title = 'Events Normalized to %s'
@@ -332,7 +336,7 @@ def plotting_worker(queue, queue_globals, options):
     while True:
         try:
             args = queue.get(timeout=5)
-        except Empty:
+        except (Empty, IOError):
             break
         process_hist(*args, **{'options':options})
         queue_globals.nfinished += 1
@@ -584,7 +588,7 @@ def process_hist_mpl(path, name, counter, options, hists):
             plt.ylim(ymin=rounded_min)
         if options.zero and not options.logy:
             plt.ylim(ymin=0.)
-        if options.ymin:
+        if options.ymin is not None:
             plt.ylim(ymin=options.ymin)
         if options.ymax:
             plt.ylim(ymax=options.ymax)
@@ -767,7 +771,7 @@ def prep_first_draw(hist, histmax, options):
     hist.SetMaximum(histmax * options.top_padding_factor)
     if options.zero and not ROOT.gPad.GetLogy():
         hist.SetMinimum(0.)
-    if options.ymin:
+    if options.ymin is not None:
         hist.SetMinimum(options.ymin)
     if options.ymax:
         hist.SetMaximum(options.ymax)
@@ -816,6 +820,8 @@ def plot_ratio_root(hists, options):
         stack_ratio.Add(ratio_hist)
     stack_ratio.Draw()
     stack_ratio.GetYaxis().SetNdivisions(507) # Avoids crowded labels
+    if options.ratio_max: stack_ratio.SetMaximum(options.ratio_max)
+    if options.ratio_min is not None: stack_ratio.SetMinimum(options.ratio_min)
     stack_ratio.Draw("nostack e")
     return stack_ratio
 
@@ -856,6 +862,8 @@ def plot_ratio_mpl(hists, options):
     plt.gca().yaxis.set_major_locator(matplotlib.ticker.MaxNLocator(
         nbins=5, steps=[1, 2, 5, 10]))
     plt.ylim(ymax=plt.ylim()[1]/1.01)
+    if options.ratio_max: plt.ylim(ymax=options.ratio_max)
+    if options.ratio_min is not None: plt.ylim(ymin=options.ratio_min)
     plt.ylabel('Ratio')
 
 def wilson(numerator, denominator):
